apply_block_householder_on_the_left_in_place_with_conj

Function apply_block_householder_on_the_left_in_place_with_conj 

pub fn apply_block_householder_on_the_left_in_place_with_conj<T: ComplexField>(
    householder_basis: MatRef<'_, T>,
    householder_factor: MatRef<'_, T>,
    conj_lhs: Conj,
    matrix: MatMut<'_, T>,
    par: Par,
    stack: &mut MemStack,
)
computes the product of the given block householder transformation, multiplied by matrix, and stores the result in matrix