apply_block_householder_on_the_right_in_place_scratch

Function apply_block_householder_on_the_right_in_place_scratch 

pub fn apply_block_householder_on_the_right_in_place_scratch<T: ComplexField>(
    householder_basis_nrows: usize,
    blocksize: usize,
    lhs_nrows: usize,
) -> StackReq
computes the size and alignment of required workspace for applying a block householder transformation to a left-hand-side matrix in place