apply_block_householder_on_the_right_in_place_with_conj

Function apply_block_householder_on_the_right_in_place_with_conj 

pub fn apply_block_householder_on_the_right_in_place_with_conj<T: ComplexField>(
    householder_basis: MatRef<'_, T>,
    householder_factor: MatRef<'_, T>,
    conj_rhs: Conj,
    matrix: MatMut<'_, T>,
    par: Par,
    stack: &mut MemStack,
)
computes the product of the matrix, multiplied by the given block householder transformation, and stores the result in matrix