pub fn apply_block_householder_sequence_on_the_left_in_place_scratch<T: ComplexField>(
householder_basis_nrows: usize,
blocksize: usize,
rhs_ncols: usize,
) -> StackReqExpand description
computes the size and alignment of required workspace for applying a sequence of block householder transformations to a right-hand-side matrix in place