pub fn apply_block_householder_transpose_on_the_right_in_place_scratch<T: ComplexField>(
householder_basis_nrows: usize,
blocksize: usize,
lhs_nrows: usize,
) -> StackReqExpand description
computes the size and alignment of required workspace for applying the transpose of a block householder transformation to a left-hand-side matrix in place